@@ -16,16 +16,20 @@
 #    <http://www.gnu.org/licenses/>
 """A Git Repository that keeps a Debian Package"""
 
+import os
 import re
+
 from gbp.command_wrappers import CommandExecFailed
-from gbp.git import GitRepository, GitRepositoryError
+from gbp.git import GitRepositoryError
 from gbp.deb.pristinetar import DebianPristineTar
 from gbp.format import format_str
+from gbp.paths import to_bin
+from gbp.pkg.git import PkgGitRepository
 
 import gbp.log
 
 
-class DebianGitRepository(GitRepository):
+class DebianGitRepository(PkgGitRepository):
     """A git repository that holds the source of a Debian package"""
 
     version_mangle_re = (r'%\(version'
@@ -44,6 +48,7 @@ class DebianGitRepository(GitRepository):
         """
         objs = self.list_tree(tree)
         new_tree_objs = []
+        dirs = [to_bin(d) for d in dirs]
 
         for m, t, s, n in objs:
             if not (n in dirs and t == 'tree'):
@@ -55,6 +60,7 @@ class DebianGitRepository(GitRepository):
         """
         Get the SHA1 of directory in a given tree
         """
+        dir = to_bin(dir)
         toplevel = self.list_tree(tree)
         for m, t, s, n in toplevel:
             if n == dir and t == 'tree':
@@ -89,6 +95,7 @@ class DebianGitRepository(GitRepository):
             if ret:
                 return None
             for line in out:
+                line = line.decode()
                 if line.endswith(" %s\n" % version):
                     # dereference to a commit object
                     return self.rev_parse("%s^0" % legacy_tag)
@@ -280,7 +287,7 @@ class DebianGitRepository(GitRepository):
         """
         return True if self.has_branch(self.pristine_tar_branch) else False
 
-    def create_pristinetar_commits(self, upstream_tree, tarball, component_tarballs):
+    def create_pristine_tar_commits(self, upstream_tree, tarball, component_tarballs):
         """
         Create pristine-tar commits for a package with main tarball tarball
         and (optional) component tarballs based on upstream_tree
@@ -297,11 +304,64 @@ class DebianGitRepository(GitRepository):
             for component, name in component_tarballs:
                 subtree = self.tree_get_dir(upstream_tree, component)
                 if not subtree:
-                    raise GitRepositoryError("No tree for '%s' found in '%s' to create pristine tar commit from" % (component, upstream_tree))
+                    raise GitRepositoryError("No tree for '%s' found in '%s' to create "
+                                             "pristine tar commit from" % (component, upstream_tree))
                 gbp.log.debug("Creating pristine tar commit '%s' from '%s'" % (component, subtree))
                 self.pristine_tar.commit(name, subtree, quiet=True)
             self.pristine_tar.commit(tarball, main_tree, quiet=True)
         except CommandExecFailed as e:
             raise GitRepositoryError(str(e))
 
+    def get_pristine_tar_commit(self, source, component=None):
+        """
+        Get the pristine-tar commit for the given source package's latest version.
+        """
+        comp = '-%s' % component if component else ''
+        return self.pristine_tar.get_commit('%s_%s.orig%s.tar.*' % (source.sourcepkg,
+                                                                    source.upstream_version,
+                                                                    comp))
+
+    def create_upstream_tarball_via_pristine_tar(self, source, output_dir, comp, component=None):
+        output = source.upstream_tarball_name(comp.type, component=component)
+        try:
+            self.pristine_tar.checkout(source.name, source.upstream_version, comp.type, output_dir,
+                                       component=component, quiet=True)
+        except Exception as e:
+            raise GitRepositoryError("Error creating %s: %s" % (output, e))
+        return True
+
+    def create_upstream_tarball_via_git_archive(self, source, output_dir, treeish,
+                                                comp, with_submodules, component=None):
+        """
+        Create a compressed orig tarball in output_dir using git archive
+
+        @param source: debian source package
+        @type source: L{DebianSource}
+        @param output_dir: output directory
+        @param type: C{str}
+        @param treeish: git treeish
+        @type treeish: C{str}
+        @param comp: compressor
+        @type comp: L{Compressor}
+        @param with_submodules: wether to add submodules
+        @type with_submodules: C{bool}
+        @param component: component to add to tarball name
+        @type component: C{str}
+
+        Raises GitRepositoryError in case of an error
+        """
+        submodules = False
+        output = os.path.join(output_dir,
+                              source.upstream_tarball_name(comp.type, component=component))
+        prefix = "%s-%s" % (source.name, source.upstream_version)
+
+        try:
+            if self.has_submodules() and with_submodules:
+                submodules = True
+                self.update_submodules()
+            self.archive_comp(treeish, output, prefix, comp, submodules=submodules)
+        except Exception as e:
+            raise GitRepositoryError("Error creating %s: %s" % (output, e))
+        return True
+
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
