@@ -28,7 +28,7 @@ from gbp.deb.upstreamsource import DebianUpstreamSource
 
 # Try to import readline, since that will cause raw_input to get fancy
 # line editing and history capabilities. However, if readline is not
-# available, raw_input will still work.
+# available, input() will still work.
 try:
     import readline  # noqa: F401
 except ImportError:
@@ -79,7 +79,7 @@ def ask_package_name(default, name_validator_func, err_msg):
     @param default: The default package name to suggest to the user.
     """
     while True:
-        sourcepackage = raw_input("What will be the source package name? [%s] " % default)
+        sourcepackage = input("What will be the source package name? [%s] " % default)
         if not sourcepackage:  # No input, use the default.
             sourcepackage = default
         # Valid package name, return it.
@@ -98,7 +98,7 @@ def ask_package_version(default, ver_validator_func, err_msg):
     @param default: The default package version to suggest to the user.
     """
     while True:
-        version = raw_input("What is the upstream version? [%s] " % default)
+        version = input("What is the upstream version? [%s] " % default)
         if not version:  # No input, use the default.
             version = default
         # Valid version, return it.
@@ -111,27 +111,27 @@ def ask_package_version(default, ver_validator_func, err_msg):
         gbp.log.warn("\nNot a valid upstream version: '%s'.\n%s" % (version, err_msg))
 
 
-def repacked_tarball_name(source, name, version):
-    if source.is_orig():
+def repacked_tarball_name(upstream, name, version):
+    if upstream.is_orig():
         # Repacked orig tarball needs a different name since there's already
         # one with that name
         name = os.path.join(
-            os.path.dirname(source.path),
-            os.path.basename(source.path).replace(".tar", ".gbp.tar"))
+            os.path.dirname(upstream.path),
+            os.path.basename(upstream.path).replace(".tar", ".gbp.tar"))
     else:
         # non tarballs (zips, unpacked dirs) get the canonical name
         name = os.path.join(
-            os.path.dirname(source.path),
-            "%s_%s.orig.tar.bz2" % (name, version))
+            os.path.dirname(upstream.path),
+            "%s_%s.orig.tar.gz" % (name, version))
     return name
 
 
-def repack_source(source, name, version, tmpdir, filters):
-    """Repack the source tree"""
-    name = repacked_tarball_name(source, name, version)
-    repacked = source.pack(name, filters)
-    if source.is_orig():  # Orig already was a tarball so it was filtered on unpack
-        repacked.unpacked = source.unpacked
+def repack_upstream(upstream, name, version, tmpdir, filters):
+    """Repack the upstream source tree"""
+    name = repacked_tarball_name(upstream, name, version)
+    repacked = upstream.pack(name, filters)
+    if upstream.is_orig():  # Orig already was a tarball so it was filtered on unpack
+        repacked.unpacked = upstream.unpacked
     else:  # otherwise unpack the generated tarball again to get a filtered tree
         if tmpdir:
             cleanup_tmp_tree(tmpdir)
@@ -168,7 +168,7 @@ def download_orig(url):
     try:
         with contextlib.closing(requests.get(url, verify=True, stream=True)) as r:
             r.raise_for_status()
-            with open(target, 'w', CHUNK_SIZE) as target_fd:
+            with open(target, 'wb', CHUNK_SIZE) as target_fd:
                 for d in r.iter_content(CHUNK_SIZE):
                     target_fd.write(d)
     except Exception as e:
