@@ -292,19 +292,17 @@ def find_upstream(use_uscan, args):
         uscan = Uscan()
         gbp.log.info("Launching uscan...")
         try:
-            uscan.scan()
+            if not uscan.scan():
+                gbp.log.info("package is up to date, nothing to do.")
+                return None
         except UscanError as e:
             raise GbpError("%s" % e)
 
-        if not uscan.uptodate:
-            if uscan.tarball:
-                gbp.log.info("Using uscan downloaded tarball %s" % uscan.tarball)
-                args.append(uscan.tarball)
-            else:
-                raise GbpError("uscan didn't download anything, and no source was found in ../")
+        if uscan.tarball:
+            gbp.log.info("Using uscan downloaded tarball %s" % uscan.tarball)
+            args.append(uscan.tarball)
         else:
-            gbp.log.info("package is up to date, nothing to do.")
-            return None
+            raise GbpError("uscan didn't download anything, and no source was found in ../")
     if len(args) > 1:  # source specified
         raise GbpError("More than one archive specified. Try --help.")
     elif len(args) == 0:
@@ -556,8 +554,8 @@ def main(argv):
             upstream = download_orig(args[0])
         else:
             upstream = find_upstream(options.uscan, args)
-        if not upstream:
-            return ExitCodes.failed
+            if not upstream:
+                return ExitCodes.uscan_up_to_date
 
         # The main tarball
         (sourcepackage, version) = detect_name_and_version(repo, upstream, options)
