@@ -2,7 +2,7 @@
 
 import sys
 from contextlib import contextmanager
-from six import StringIO
+from io import StringIO
 
 
 class _StderrCapture(StringIO):
